#wrapper #content a             { text-decoration: none }
#wrapper #content a:hover       { text-decoration: underline }
#wrapper #content #doi          { margin-bottom: 20px; padding: .5em; border-radius: .25em; width: 500px; }
#wrapper #content #doi span.doi-label { color: #fff; background-color: #000; padding: 5px; font-weight: bold; border-radius: .25em 0em 0em .25em; }
#wrapper #content #doi span.doi-value { color: #000; background-color: #f0f0f0; padding: 5px; border-radius: 0em .25em .25em 0em; }
#wrapper #content #doi #container_doi       { display: none; position: absolute; background-color: #fff; width: 500px; border: 2px solid #000; padding:5px }
#wrapper #content #doi:hover #container_doi { display: block }
#wrapper #content #type         { text-transform: uppercase; font-weight: bold }
#wrapper #content #metadata #versions { margin-top: 0px }
#wrapper #content #description  { margin-top: 10px; padding:10px; border: 1px solid #666; border-radius: 10px }
#wrapper #content #description p { margin-top: 0; margin-bottom:0 }
#wrapper #content #authors img, #contributors img  { height: 15px }
#wrapper #content .metric       { float: left; margin:5px; text-align: center }
#wrapper #content .metric .number { font-size: 24px; font-weight: bold }
#wrapper #content #categories   { padding-top: 10px; clear: left }
#wrapper #content #tags, #geo, #time_coverage, #dates, #collections, #peer, #references, #publisher, #format, #organizations,
#wrapper #content #contributors, #funding, #usage, #derived_from, #same_as, #language, #licence, #export, #data_link, #code-hosting-url
                                { margin-top: 10px }
#wrapper #content #funding ul   { list-style-type: square; margin-left: 20px }
#wrapper #content #funding .funder_name { display: block; color: #999 }
#wrapper #content #files .size  { display: inline-block; width:120px; font-size:12px; color: #999; text-align:right; margin-right:5px }
#wrapper #content #files .md5   { font-size: 75%;  color: #333; font-family: monospace; margin: auto 1em auto 1em; }
#wrapper #content #metadata #left_column  { width: 65%; margin-bottom:10px }
#wrapper #content #metadata #right_column { float: right; width: 33%; margin-bottom:10px }
#wrapper #content .warning      { background-color: #ff0 }
#wrapper #content .label        { text-transform: uppercase }
#wrapper #content ul            { list-style-type: none; padding:0; margin:0}
#wrapper #content #data         { clear: right; border-top: 1px solid #000; margin-bottom: 10px }
#wrapper #content #collect,      #cite,      #versions      { display: none; border: 3px solid #f39000; padding: 10px; margin-bottom:10px; border-radius: 10px }
#wrapper #content #collect_show, #cite_show                 { border: none; padding:3px; margin-bottom: 10px; border-radius: 10px; text-aligh: center; width:70px }
#wrapper #content #collect_hide, #cite_hide, #versions_hide { border: none }
#wrapper #content #citation     { font-weight: bold }
#wrapper #content #type_versions { margin-bottom:10px }
#wrapper #content #versions     { width: 220px; position:absolute; background-color: #fff }
#wrapper #content #versions_show { padding: 2px 10px 2px 10px; border: none; background-color: #fff; font: inherit; font-size: inherit; }
#wrapper #content #versions_show:hover { text-decoration: underline; cursor: pointer }
#wrapper #content #versions a   { display: block }
#wrapper #content #versions div { color: #999 }
#wrapper #content .is_active    { font-weight: bold }
#wrapper #content .small        { font-size: 75%; opacity: 0.8 }
#wrapper #content #orcid img    { height: 20px }
#wrapper #content #has-account  { margin-top: 80px; clear: both }
#wrapper #content #limited_access p { margin-top: 5px; margin-bottom: 5px }
#wrapper #content #limited_access h4 { margin-top: 10px; margin-bottom: 0px }
#wrapper #content #is_own_item { padding:5px; border-radius:5px; background-color: #ffeeaa }
#wrapper #content #private_view { padding:5px; border-radius:5px; background-color: #ffeeaa }
